@@ -170,7 +170,7 @@ class PAOFLOW:
 
 
 
-  def restart_load ( self, fname_prefix ):
+  def restart_load ( self, fname_prefix='paoflow_dump' ):
     '''
       Loads the previously dumped save files and populates the DataController with said data.
 
